Thank you goes to the following kind people.

The following people have been involved in this project by consulting, developing and testing.

[Alixander Court](https://alixandercourt.com/)

[edhelas](https://github.com/edhelas/atomtopubsub)

Guus der Kinderen (promptly dedicating a personal [Openfire](https://www.igniterealtime.org/projects/) server for further developments and tests)

[habnabit_](irc://irc.libera.chat/#python) (SQL security)

[imattau](https://github.com/imattau/atomtopubsub) (Some code, mostly URL handling, was taken from imattau)

[Link Mauve](https://linkmauve.fr/contact.xhtml)

magicfelix (async)

Simone "roughnecks" Canaletti

Strix from Loqi

Slixmpp participants and #python members who explicitly chose to remain anonymous or not to appear in this list.
